summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoPictureClipart.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoPictureClipart.h')
-rw-r--r--lib/kofficecore/KoPictureClipart.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/lib/kofficecore/KoPictureClipart.h b/lib/kofficecore/KoPictureClipart.h
index 9784c673..b390bca3 100644
--- a/lib/kofficecore/KoPictureClipart.h
+++ b/lib/kofficecore/KoPictureClipart.h
@@ -20,11 +20,11 @@
#ifndef __koPictureClipart_h__
#define __koPictureClipart_h__
-#include <qstring.h>
-#include <qpicture.h>
+#include <tqstring.h>
+#include <tqpicture.h>
-class QPainter;
-class QSize;
+class TQPainter;
+class TQSize;
// TODO: fix documentation
@@ -64,39 +64,39 @@ public:
* Note that the image is being scaled to that size using scale() - except when printing.
* This avoids scaling the image at each paint event.
*
* The other parameters are very similar to QPainter::drawPixmap :
* (@p x, @p y) define the position in the painter,
* (@p sx, @p sy) specify the top-left point in pixmap that is to be drawn. The default is (0, 0).
* (@p sw, @p sh) specify the size of the pixmap that is to be drawn. The default, (-1, -1), means all the way to the bottom
* right of the pixmap.
*/
- virtual void draw(QPainter& painter, int x, int y, int width, int height, int sx = 0, int sy = 0, int sw = -1, int sh = -1, bool fastMode = false);
+ virtual void draw(TQPainter& painter, int x, int y, int width, int height, int sx = 0, int sy = 0, int sw = -1, int sh = -1, bool fastMode = false);
- virtual bool loadData(const QByteArray& array, const QString& extension);
+ virtual bool loadData(const TQByteArray& array, const TQString& extension);
/**
* save file
* @param io QIODevice used for saving
*/
- virtual bool save(QIODevice* io) const;
+ virtual bool save(TQIODevice* io) const;
- virtual QSize getOriginalSize(void) const;
+ virtual TQSize getOriginalSize(void) const;
- virtual QPixmap generatePixmap(const QSize& size, bool smoothScale = false);
+ virtual TQPixmap generatePixmap(const TQSize& size, bool smoothScale = false);
- virtual QString getMimeType(const QString& extension) const;
+ virtual TQString getMimeType(const TQString& extension) const;
protected:
- QPixmap getPixmap(QImage& image);
+ TQPixmap getPixmap(TQImage& image);
/**
* @internal
- * Draw a QPicture
+ * Draw a TQPicture
*/
- void drawQPicture(QPicture& clipart, QPainter& painter,
+ void drawTQPicture(TQPicture& clipart, TQPainter& painter,
int x, int y, int width, int height, int sx, int sy, int sw, int sh);
protected:
- QPicture m_clipart; ///< The clipart as QPicture
- QByteArray m_rawData; ///< Copy of the loaded image file
+ TQPicture m_clipart; ///< The clipart as TQPicture
+ TQByteArray m_rawData; ///< Copy of the loaded image file
};
#endif /* __koPictureClipart_h__ */
@@ -64,39 +64,39 @@ public:
* This avoids scaling the image at each paint event.
*
- * The other parameters are very similar to QPainter::drawPixmap :
+ * The other parameters are very similar to TQPainter::drawPixmap :
* (@p x, @p y) define the position in the painter,
* (@p sx, @p sy) specify the top-left point in pixmap that is to be drawn. The default is (0, 0).
@@ -64,39 +64,39 @@ public:
/**
* save file
- * @param io QIODevice used for saving
+ * @param io TQIODevice used for saving
*/